=====
Gluon
=====

A Model-Driven, Extensible Framework for Networking APIs

Gluon provides a framework for specifying, using a model file,
APIs for network forwarding.  It is intended to offer devs
the possibility of quickly prototyping any networking forwarding
system that describes how a packet moves from port to port or
port to the outside world.

* Free software: Apache license
* Documentation: http://docs.openstack.org/developer/gluon
* Source: http://git.openstack.org/cgit/openstack/gluon
* Bugs: http://bugs.launchpad.net/python-gluon

Features
--------

* TODO
